/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/**
@fileoverview
Utility functions.
*/

function MozileBug()
{
	this.data = new Array();
} 

/**
Opens the Debug window.
*/
MozileBug.prototype.open = function ()
{
	window.openDialog("chrome://mozile/content/XUL/debugging.xul", "mozileDebug", "centerscreen,chrome,resizable=yes", this);
};

MozileBug.prototype.reset = function ()
{
	this.data = new Array();
};

/**
Gets the current debugLevel from the Mozile preferences.

@return debugLevel
@type Integer
*/
MozileBug.prototype.debugLevel = function ()
{
	return mozilePrefs.getIntPref("mozile.debugLevelInt");
};

/**
Writes a debugging message.

Mozile Debug Levels.
0 = Really important, alert the user right away, add to debug array
1 = Important, always show this in the status, add to debug array
2 = Not important, add to debug array
3 = Unimportant, add to debug array

Mozile Debug preference:
0 = disabled :: ignore Levels 2 and 3
1 = minimum :: ignore Level 3
2 = full :: process all Levels

@param {Array} f (strings) filename and function
@param {Integer} level debug level 0 to 3 inclusive
@param {String} msg debug message
@param {Boolean} minimise (optional) true = show a minimal Level 0 message without "f"
*/
MozileBug.prototype.write = function (f,level,msg,minimise)
{
	var debugLevel = mozilePrefs.getIntPref("mozile.debugLevelInt");
	if( !((level >= 2 && debugLevel === 0) || (level == 3 && debugLevel < 2)) ) {
		var now = new Date();
		var datestamp = now.toLocaleString();
		this.data.push([datestamp,f,level,msg]);
		if (this.data.length > 250) {
			this.data.shift();
		}

		if(level === 0) {
		// Critical message : pop up alert
			if (minimise) {
				alert(msg);
			} else {
				alert ( "Mozile: ["+ f +"] "+ msg );
			}
		}
		else if (level == 1) {
			var Wwindow = new XPCNativeWrapper(content, "window", "status");
			Wwindow.status = "Mozile: " + msg.substr(0,250);
		}
	}
};




/**
Custom Mozile Dialog.

To be expanded as needed.
*/
function mozileDialog( content ) {
	var win = window.openDialog("chrome://mozile/content/XUL/mdialog.xul",
		"moziledialog", "modal,centerscreen,chrome,resizable=yes,scrollbars=yes", content );
}




/**
Opens a file in the current browser window, a new tab, or a new window.
*/
function mozileOpen( location, method ) {
	var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
	var mrw = wm.getMostRecentWindow("navigator:browser");
	switch ( method ) {
		case "window":
			window.open(location);
			break;
		case "tab":
			var browser = mrw.getBrowser();
			browser.addTab(location);
			break;
		default: //"browser"
			mrw.content.window.location=location;
	}
}

/**
Opens a file via a context popup menu.
*/
function mozileOpenNew( method ) {
	var popupNode = document.popupNode; //Get what opened the popup.
	var id = popupNode.getAttribute( "id" );
	var location;
	switch ( method ) {
		case "window":
		case "tab":
		case "browser":
			break;
		default:
			method="window";
	}
	switch ( id ) {
		case "mozile-demo":
			location = MOZILEC.DEMO;
			break;
		case "mozile-home":
			location = MOZILEC.HOME;
			break;
		default: //"mozile-help"
			location = MOZILEC.HELP;
	}
	mozileOpen( location, method );

	//Close Mozile main menu.
	document.getElementById("mozile-menu-popup").hidePopup();
}
